@@ -19,13 +19,25 @@ for line in file( version_details ):
     key, value = [s.strip() for s in line.split('=',1)]
     branding_info[ key ] = value
 
-build_revision = os.popen( 'svnversion -c "%s" 2>&1' % os.environ.get( 'PYSVN_EXPORTED_FROM', '..' ), 'r' ).read().strip()
+svnversion_image = os.environ.get( 'PYSVN_SVNVERSION', 'svnversion' )
+if ' ' in svnversion_image:
+    cmd = ('"%s" -c "%s" 2>&1' %
+        (svnversion_image
+        ,os.environ.get( 'PYSVN_EXPORTED_FROM', '..' )))
+else:
+    cmd = ('%s -c "%s" 2>&1' %
+        (svnversion_image
+        ,os.environ.get( 'PYSVN_EXPORTED_FROM', '..' )))
+
+print 'Info: Running %s' % cmd
+build_revision = os.popen( cmd, 'r' ).read().strip()
+
 # build_revision is either a range nnn:mmm or mmm
 # we only want the mmm
 build_revision = build_revision.split(':')[-1]
 print 'Info: revision %s' % build_revision
 
-if build_revision.find( 'exported' ) >= 0:
+if build_revision[0] not in '0123456789':
     branding_info['BUILD'] = '0'
 else:
     revision, modifiers = re.compile( '(\d+)(.*)' ).search( build_revision ).groups()
