@@ -53,7 +53,7 @@ print 'Info: Copy files'
 kit_files_info = [
 	('../../Source/pysvn/__init__.py',
 		'ROOT/usr/lib/python%(pymaj)d.%(pymin)d/site-packages/pysvn', '444'),
-	('../../Source/pysvn/_pysvn.so',
+	('../../Source/pysvn/_pysvn_%(pymaj)d_%(pymin)d.so' % locals(),
 		'ROOT/usr/lib/python%(pymaj)d.%(pymin)d/site-packages/pysvn', '444'),
 	('../../LICENSE.txt',
 		'ROOT/usr/share/doc/pysvn', '444'),
@@ -83,12 +83,12 @@ Version:	%(pysvn_version_package_string)s
 Group:		Development/Libraries
 Release:	%(pysvn_version_package_release_string)s
 Summary:	pysvn %(pysvn_version_package_string)s Python extension for Subversion %(svn_version_string)s
-License:	Apache Software License, Version 1.1 - Copyright Barry A. Scott (c) 2003-2006
+License:	Apache Software License, Version 1.1 - Copyright Barry A. Scott (c) 2003-2007
 Packager:	Barry A. Scott <barry@barrys-emacs.org>
 %%description
 PySVN %(pysvn_version_string)s for Python %(python_version_string)s and Subversion %(svn_version_string)s
 
-Copyright Barry A. Scott (c) 2003-2006
+Copyright Barry A. Scott (c) 2003-2007
 
 mailto:barry@barrys-emacs.org
 http://pysvn.tigris.org
