@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -20,8 +20,14 @@
 #include "pysvn.hpp"
 #include "pysvn_docs.hpp"
 
+
 //--------------------------------------------------------------------------------
 
+static apr_time_t toAprTime( double t_in )
+{
+    return apr_time_t( t_in * 1000000 );
+}
+
 pysvn_revision::pysvn_revision
     (
     svn_opt_revision_kind kind,
@@ -29,9 +35,14 @@ pysvn_revision::pysvn_revision
     int revnum
     )
 {
+    memset( &m_svn_revision, 0, sizeof( m_svn_revision ) );
+
     m_svn_revision.kind = kind;
-    m_svn_revision.value.date = apr_time_t( date * 1000000 );
-    m_svn_revision.value.number = revnum;
+    if( kind == svn_opt_revision_date )
+        m_svn_revision.value.date = toAprTime( date );
+
+    if( kind == svn_opt_revision_number )
+        m_svn_revision.value.number = revnum;
 }
 
 pysvn_revision::~pysvn_revision()
@@ -43,6 +54,37 @@ const svn_opt_revision_t &pysvn_revision::getSvnRevision() const
     return m_svn_revision;
 }
 
+Py::Object pysvn_revision::repr()
+{
+    std::string s("<Revision kind=");
+    s += toString( m_svn_revision.kind );
+
+    switch( m_svn_revision.kind )
+    {
+        case svn_opt_revision_number:
+            {
+            char buf[80];
+            snprintf( buf, sizeof(buf), " %d", int(m_svn_revision.value.number) );
+            s += buf;
+            }
+            break;
+
+        case svn_opt_revision_date:
+            {
+            char buf[300];
+            snprintf( buf, sizeof(buf), " %f", double( m_svn_revision.value.date )/1000000 );
+            s += buf;
+            }
+            break;
+
+        default:
+            break;
+    }
+    s += ">";
+
+    return Py::String( s );
+}
+
 Py::Object pysvn_revision::getattr( const char *_name )
 {
     std::string name( _name );
@@ -77,8 +119,7 @@ Py::Object pysvn_revision::getattr( const char *_name )
         else
             return Py::Nothing();
     }
-    else
-        return getattr_methods( _name );
+    return getattr_methods( _name );
 }
 
 int pysvn_revision::setattr( const char *_name, const Py::Object &value )
@@ -93,8 +134,7 @@ int pysvn_revision::setattr( const char *_name, const Py::Object &value )
     else if( name == "date" )
     {
         Py::Float py_date( value );
-        apr_time_t date = (apr_time_t)( double( py_date ) * 1000000 );
-        m_svn_revision.value.date = date;
+        m_svn_revision.value.date = toAprTime( double( py_date ) );
     }
     else if( name == "number" )
     {
@@ -107,10 +147,10 @@ int pysvn_revision::setattr( const char *_name, const Py::Object &value )
     return 0;
 }
 
-
 void pysvn_revision::init_type()
 {
     behaviors().name("revision");
-    behaviors().doc( class_revision_doc );
+    behaviors().doc( pysvn_revision_doc );
     behaviors().supportGetattr();
+    behaviors().supportRepr();
 }
