@@ -60,6 +60,8 @@ SvnException::SvnException( svn_error_t *error )
     arg_list[1] = error_list;
 
     m_exception_arg = arg_list;
+
+    svn_error_clear( error );
 }
 
 SvnException::SvnException( const SvnException &other )
@@ -468,11 +470,10 @@ SvnContext::~SvnContext()
 {
     delete m_config_dir;
 
-// Why isn't the pool release - object life time problems?
-//    if( m_pool )
-//    {
-//        apr_pool_destroy( m_pool );
-//    }
+    if( m_pool )
+    {
+        apr_pool_destroy( m_pool );
+    }
 }
 
 SvnContext::operator svn_client_ctx_t *()
