@@ -65,6 +65,8 @@
 #define PYSVN_HAS_CONTEXT_LOG_MSG2
 #define PYSVN_HAS_CONTEXT_PROGRESS
 
+#define PYSVN_HAS_WC_ADM_DIR
+
 #define PYSVN_HAS_CLIENT_ADD3
 #define PYSVN_HAS_CLIENT_COMMIT3
 #define PYSVN_HAS_CLIENT_COPY2
@@ -77,6 +79,21 @@
 #define PYSVN_HAS_CLIENT_MOVE3
 #endif
 
+// SVN 1.4 or later
+#if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 4) || SVN_VER_MAJOR > 1
+#define PYSVN_HAS_CLIENT_ANNOTATE3
+#define PYSVN_HAS_CLIENT_COPY3
+#define PYSVN_HAS_CLIENT_DIFF_SUMMARIZE
+#define PYSVN_HAS_CLIENT_LIST
+#define PYSVN_HAS_CLIENT_LOG3
+#define PYSVN_HAS_CLIENT_MERGE2
+#define PYSVN_HAS_CLIENT_MERGE_PEG2
+#define PYSVN_HAS_CLIENT_MOVE4
+#define PYSVN_HAS_DIFF_FILE_IGNORE_SPACE
+#define PYSVN_HAS_SVN_AUTH_PROVIDERS
+#endif
+
+
 #ifdef PYSVN_HAS_CLIENT_STATUS2
 typedef svn_wc_status2_t pysvn_wc_status_t;
 #else
@@ -139,6 +156,10 @@ public:
     operator svn_client_ctx_t *();
     svn_client_ctx_t *ctx();
 
+    // only use this pool for data that has a life time
+    // that matches the life time of the context
+    apr_pool_t          *getContextPool();
+
     //
     // this method will be called to retrieve
     // authentication information
@@ -246,8 +267,9 @@ public:
         ) = 0;
 
 private:
+#if 0
 #ifdef PYSVN_HAS_CONTEXT_LOG_MSG2
-    static svn_error_t *handlerLogMsg2
+    extern "C" static svn_error_t *handlerLogMsg2
         (
         const char **log_msg,
         const char **tmp_file,
@@ -256,7 +278,7 @@ private:
         apr_pool_t *pool
         );
 #else
-    static svn_error_t *handlerLogMsg
+    extern "C" static svn_error_t *handlerLogMsg
         (
         const char **log_msg,
         const char **tmp_file,
@@ -267,7 +289,7 @@ private:
 #endif
 
 #ifdef PYSVN_HAS_CONTEXT_PROGRESS
-    static void handlerProgress
+    extern "C" static void handlerProgress
         (
         apr_off_t progress,
         apr_off_t total,
@@ -277,14 +299,14 @@ private:
 #endif
 
 #ifdef PYSVN_HAS_CONTEXT_NOTIFY2
-    static void handlerNotify2
+    extern "C" static void handlerNotify2
         (
         void * baton,
 	const svn_wc_notify_t *notify,
 	apr_pool_t *pool        
         );
 #else
-    static void handlerNotify
+    extern "C" static void handlerNotify
         (
         void * baton,
         const char *path,
@@ -296,12 +318,12 @@ private:
         svn_revnum_t revision
         );
 #endif
-    static svn_error_t *handlerCancel
+    extern "C" static svn_error_t *handlerCancel
         (
         void * baton
         );
 
-    static svn_error_t *handlerSimplePrompt
+    extern "C" static svn_error_t *handlerSimplePrompt
         (
         svn_auth_cred_simple_t **cred,
         void *baton,
@@ -311,7 +333,7 @@ private:
         apr_pool_t *pool
         );
 
-    static svn_error_t *handlerSslServerTrustPrompt 
+    extern "C" static svn_error_t *handlerSslServerTrustPrompt 
         (
         svn_auth_cred_ssl_server_trust_t **cred, 
         void *baton,
@@ -322,14 +344,14 @@ private:
         apr_pool_t *pool
         );
 
-    static svn_error_t *handlerSslClientCertPrompt 
+    extern "C" static svn_error_t *handlerSslClientCertPrompt 
         (
         svn_auth_cred_ssl_client_cert_t **cred, 
         void *baton, 
         apr_pool_t *pool
         );
 
-    static svn_error_t *handlerSslClientCertPwPrompt
+    extern "C" static svn_error_t *handlerSslClientCertPwPrompt
         (
         svn_auth_cred_ssl_client_cert_pw_t **cred, 
         void *baton, 
@@ -337,8 +359,7 @@ private:
         svn_boolean_t maySave,
         apr_pool_t *pool
         );
-
-
+#endif
 private:
     apr_pool_t          *m_pool;
     svn_client_ctx_t    m_context;
