@@ -1,6 +1,6 @@
 #
 # ====================================================================
-# (c) 2005-2006 Barry A Scott.  All rights reserved.
+# (c) 2005-2007 Barry A Scott.  All rights reserved.
 #
 # This software is licensed as described in the file LICENSE.txt,
 # which you should have received as part of this distribution.
@@ -59,6 +59,7 @@ def setup_help( argv ):
         --svn-inc-dir=<dir>
         --svn-lib-dir=<dir>
         --define=<define-string>
+        --universal (build Mac OS X universal binary - not working at yet)
 
 ''' % (basename, basename)
     return 1
@@ -70,6 +71,7 @@ class MakeFileCreater:
         self.is_mac_os_x_fink = False
         self.is_mac_os_x_darwin_ports = False
         self.mac_os_x_version = None
+        self.mac_os_x_universal = False
 
     def node_text( self, all_nodes ):
         all_text = []
@@ -98,16 +100,27 @@ class MakeFileCreater:
                     self.mac_os_x_version = [int(s) for s in self.mac_os_x_version_string.split('.')]
                     self.is_mac_os_x = True
 
+                    # look for the universal SDK
+                    self.mac_os_x_universal = os.path.exists( '/Developer/SDKs/MacOSX%d.%du.sdk' %
+                                                (self.mac_os_x_version[0], self.mac_os_x_version[1]) )
+                    if self.mac_os_x_universal:
+                        print 'Info: Mac OS X Universal SDKs found'
 
     def createMakefile( self, argv ):
         self.verbose = '--verbose' in argv
         self.detectMacVersion()
+        if '--universal' in argv and self.mac_os_x_universal:
+            print 'Info: turning on universal support'
+            self.mac_os_x_universal = True
+        else:
+            self.mac_os_x_universal = False
 
         if self.verbose:
             print 'Info: Creating makefile for python %r' % (sys.version_info,)
 
         debug_cflags_list = []
         if '--enable-debug' in argv:
+            print 'Info: Enabling debug'
             debug_cflags_list.append( '-g' )
 
         include_dir_list = []
@@ -137,8 +150,6 @@ class MakeFileCreater:
         for flag in py_cflags_python_list:
             if flag.startswith( '-D' ):
                 py_cflags_list.append( flag )
-            if flag.startswith( '-O' ) or flag.startswith( '-f' ) or flag.startswith( '-g' ):
-                py_cflags_list.append( flag )
 
         # add platform specific defines
         if self.is_mac_os_x:
@@ -155,9 +166,11 @@ class MakeFileCreater:
         py_cflags_list.append( '-Dinit_pysvn=init_pysvn_%d_%d' % sys.version_info[:2] )
         py_cflags_list.append( '-Dinit_pysvn_d=init_pysvn_%d_%d_d' % sys.version_info[:2] )
 
+        module_type = '.so'
+        if sys.platform == 'cygwin':
+            module_type = '.dll'
         template_values = {
-#            'pysvn_module_name': '_pysvn_%d_%d' % sys.version_info[:2],
-            'pysvn_module_name': '_pysvn',
+            'pysvn_module_name': '_pysvn_%d_%d%s' % (sys.version_info[0], sys.version_info[1], module_type),
 
             # python executable
             'python_exe':       sys.executable,
@@ -200,7 +213,7 @@ class MakeFileCreater:
 
                 # 10.4 needs the libintl.a but 10.3 does not
                 template_values['extra_libs'] = '%(svn_lib_dir)s/libintl.a' % template_values
-                template_values['frameworks'] = '-framework System %s -framework CoreFoundation -framework Kerberos' % framework_lib
+                template_values['frameworks'] = '-framework System %s -framework CoreFoundation -framework Kerberos -framework Security' % framework_lib
             else:
                 if self.verbose:
                     print 'Info: Using Mac OS X 10.3 makefile template'
@@ -214,8 +227,11 @@ class MakeFileCreater:
             elif self.is_mac_os_x_darwin_ports:
                 makefile.write( self.makefile_template_macosx_darwin_ports % template_values )
 
+            elif self.mac_os_x_universal:
+                makefile.write( self.makefile_template_macosx_universal % template_values )
             else:
-                makefile.write( self.makefile_template_macosx % template_values )
+                makefile.write( self.makefile_template_macosx_one_arch % template_values )
+
         elif sys.platform.startswith('aix'):
             if self.verbose:
                 print 'Info: Using AIX makefile template'
@@ -232,10 +248,23 @@ class MakeFileCreater:
                 else:
                     template_values['python_exp'] = 'python.exp'
             makefile.write( self.makefile_template_aix % template_values )
+
         elif sys.platform.startswith('linux'):
             if self.verbose:
                 print 'Info: Using Linux makefile template'
             makefile.write( self.makefile_template_linux % template_values )
+
+        elif sys.platform.startswith('freebsd'):
+            if self.verbose:
+                print 'Info: Using FreeBSD makefile template'
+            makefile.write( self.makefile_template_freebsd % template_values )
+
+        elif sys.platform == 'cygwin':
+            if self.verbose:
+                print 'Info: Using Cygwin makefile template'
+            makefile.write( self.makefile_template_cygwin % template_values )
+
+
         else:
             if self.verbose:
                 print 'Info: Using unix makefile template'
@@ -301,7 +330,68 @@ LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
 -lsvn_client-1 \
 -lsvn_diff-1 \
--lsvn_repos-1 `apr-config --link-ld --libs`
+-lsvn_repos-1 \
+ -lgssapi_krb5 -lkrb5 -lk5crypto -lkrb5support -lcom_err -lresolv -lexpat -lneon
+
+#include pysvn_common.mak
+'''
+
+    makefile_template_freebsd = '''#
+#	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_freebsd --
+#
+PYTHON=%(python_exe)s
+SVN_INCLUDE=%(svn_include)s
+CCC=g++ -c
+CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
+CC=gcc -c
+CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
+PYCXX=%(pycxx_dir)s
+LDSHARED=g++ -shared %(debug_cflags)s
+LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,/usr/lib:/usr/local/lib:%(svn_lib_dir)s \
+-lsvn_client-1 \
+-lsvn_diff-1 \
+-lsvn_repos-1 \
+ -lkrb5 -lcom_err -lexpat -lneon
+
+#include pysvn_common.mak
+'''
+
+    makefile_template_cygwin = '''#
+#	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_cygwin --
+#
+PYTHON=%(python_exe)s
+SVN_INCLUDE=%(svn_include)s
+CCC=g++ -c
+CCCFLAGS=-Wall -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
+CC=gcc -c
+CCFLAGS=-Wall %(includes)s %(debug_cflags)s
+PYCXX=%(pycxx_dir)s
+LDSHARED=g++ -shared %(debug_cflags)s
+LDLIBS=-L%(svn_lib_dir)s \
+-L/usr/lib/python2.5/config -lpython2.5.dll \
+-lsvn_client-1   \
+-lsvn_repos-1    \
+-lsvn_subr-1     \
+-lsvn_delta-1    \
+-lsvn_fs_fs-1    \
+-lsvn_fs-1       \
+-lsvn_ra_svn-1   \
+-lsvn_repos-1    \
+-lsvn_ra_local-1 \
+-lsvn_ra_dav-1   \
+-lsvn_diff-1     \
+-lsvn_ra-1       \
+-lsvn_wc-1       \
+-lapr-1          \
+-lneon           \
+-laprutil-1      \
+-liconv          \
+-lexpat          \
+-lpthread        \
+-lz              \
+
 
 #include pysvn_common.mak
 '''
@@ -345,9 +435,9 @@ LDLIBS=-L%(svn_lib_dir)s \
 #include pysvn_common.mak
 '''
 
-    makefile_template_macosx = '''#
+    makefile_template_macosx_one_arch = '''#
 #	Created by pysvn Extension/Source/setup.py
-#       -- makefile_template_macosx --
+#       -- makefile_template_macosx_one_arch --
 #
 PYTHON=%(python_exe)s
 SVN_INCLUDE=%(svn_include)s
@@ -367,6 +457,31 @@ LDLIBS=-L%(svn_lib_dir)s \
 -lsvn_diff-1 \
 -l%(lib_apr)s
 #include pysvn_common.mak
+'''
+
+    makefile_template_macosx_universal = '''#
+#	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_macosx_universal --
+#
+PYTHON=%(python_exe)s
+SVN_INCLUDE=%(svn_include)s
+CCC=g++ -c
+CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s -isysroot /Developer/SDKs/MacOSX10.4u.sdk -arch ppc -arch i386
+CC=gcc -c
+CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s -isysroot /Developer/SDKs/MacOSX10.4u.sdk -arch ppc -arch i386
+PYCXX=%(pycxx_dir)s
+LDSHARED=g++ -bundle -twolevel_namespace %(debug_cflags)s -u _PyMac_Error %(frameworks)s -Wl,-syslibroot,/Developer/SDKs/MacOSX10.4u.sdk -arch ppc -arch i386
+LDLIBS=-L%(svn_lib_dir)s \
+-L%(apr_lib_dir)s \
+-lsvn_client-1 \
+-lsvn_repos-1 \
+-lsvn_wc-1 \
+-lsvn_fs-1 \
+-lsvn_subr-1 \
+-lsvn_diff-1 \
+-lsvn_ra_dav-1 \
+-l%(lib_apr)s
+#include pysvn_common.mak
 '''
 
     makefile_template_macosx_fink = '''#
@@ -450,13 +565,12 @@ LDLIBS= \
 '''
 
     def find_pycxx( self, argv ):
-        return '/usr/share/python%s/CXX' % sys.version[:3]
         return self.find_dir( argv,
                     'PyCXX include',
                     '--pycxx-dir=',
                     None,
                     [   '../Import/pycxx-5.4.0'],
-                    'cxxsupport.cxx' )
+                    'CXX/Version.hxx' )
 
     def find_svn_inc( self, argv ):
         return self.find_dir( argv,
@@ -486,7 +600,7 @@ LDLIBS= \
                         '/usr/local/lib',                       # typical *BSD
                         '/usr/pkg/lib',                         # netbsb
                     ],
-                    self.is_mac_os_x and 'libsvn_client-1.dylib' or 'libsvn_client-1.so' )
+                    self.get_lib_name_for_platform( 'libsvn_client-1' ) )
         # if we are using the Fink SVN then remember this
         self.is_mac_os_x_fink = dir.startswith( '/sw/' )
         self.is_mac_os_x_darwin_ports = dir.startswith( '/opt/local/' )
@@ -494,7 +608,7 @@ LDLIBS= \
 
     def find_apr_inc( self, argv ):
         last_exception = None
-        for apr_ver in ['apr-1.0', 'apr-1', 'apr-0']:
+        for apr_ver in ['apr-1', 'apr-0']:
             try:
                 return self.find_dir( argv,
                     'APR include',
@@ -530,9 +644,10 @@ LDLIBS= \
 
     def find_apr_lib( self, argv ):
         last_exception = None
-        for apr_libname, self.lib_apr in [
-                            (self.is_mac_os_x and 'libapr-1.dylib' or 'libapr-1.so', 'apr-1'),
-                            (self.is_mac_os_x and 'libapr-0.dylib' or 'libapr-0.so', 'apr-0')]:
+        lib_list = [(self.get_lib_name_for_platform( 'libapr-1' ), 'apr-1'),
+                    (self.get_lib_name_for_platform( 'libapr-0' ), 'apr-0')]
+
+        for apr_libname, self.lib_apr in lib_list:
             try:
                 return self.find_dir( argv,
                     'APR library',
@@ -543,9 +658,7 @@ LDLIBS= \
             except SetupError:
                 pass
 
-        for apr_libname, self.lib_apr in [
-                            (self.is_mac_os_x and 'libapr-1.dylib' or 'libapr-1.so', 'apr-1'),
-                            (self.is_mac_os_x and 'libapr-0.dylib' or 'libapr-0.so', 'apr-0')]:
+        for apr_libname, self.lib_apr in lib_list:
             try:
                 return self.find_dir( argv,
                     'APR library',
@@ -567,6 +680,14 @@ LDLIBS= \
         raise last_exception
 
 
+    def get_lib_name_for_platform( self, libname ):
+        if self.is_mac_os_x:
+            return '%s.dylib' % libname
+        elif sys.platform == 'cygwin':
+            return '%s.dll.a' % libname
+        else:
+            return '%s.so' % libname
+
     def find_dir( self, argv, name, kw, svn_root_suffix, base_dir_list, check_file ):
         dirname = self.__find_dir( argv, name, kw, svn_root_suffix, base_dir_list, check_file )
         print 'Info: Found %14.14s in %s' % (name, dirname)
