@@ -1,7 +1,6 @@
 #!/bin/sh
 # need to get rid of any symbolic links in the WORKDIR
-cd ${WORKDIR}
-export WORKDIR=$( $PYTHON -c 'import os;print os.getcwd()' )
+export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print os.getcwd()' )
 
 cd ${WORKDIR}/Tests
 echo WorkDir: ${WORKDIR}
@@ -57,7 +56,6 @@ echo Info: test_1.output start ----------------------------------------
 cat ${TESTROOT}/test_1.output
 echo Info: test_1.output end ------------------------------------------
 
-
 echo Info: Mod one file Mod one prop
 
 echo file1 ROOT ln 2 > ${TESTROOT}/wc/file1.txt
@@ -66,3 +64,11 @@ cmd ${PYSVN} checkin -m "Mod one file Mod one prop" ${TESTROOT}/wc
 echo Info: test_1.output start ----------------------------------------
 cat ${TESTROOT}/test_1.output
 echo Info: test_1.output end ------------------------------------------
+
+echo Info: Delete one file
+
+cmd ${PYSVN} rm ${TESTROOT}/wc/a/file1.txt
+cmd ${PYSVN} checkin -m "Delete one file" ${TESTROOT}/wc
+echo Info: test_1.output start ----------------------------------------
+cat ${TESTROOT}/test_1.output
+echo Info: test_1.output end ------------------------------------------
