@@ -1,7 +1,6 @@
 #!/bin/sh
 # need to get rid of any symbolic links in the WORKDIR
-cd ${WORKDIR}
-export WORKDIR=$( $PYTHON -c 'import os;print os.getcwd()' )
+export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print os.getcwd()' )
 
 cd ${WORKDIR}/Tests
 echo WorkDir: ${WORKDIR}
